==> exceljs-0.2.12.tgz: package/lib/xlsx/xform/sheet/hyperlink-map.js <==
/**
 * Copyright (c) 2016 Guyon Roche
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 */
'use strict';

var _ = require('underscore');

var HyperlinkMap = function(relationships, hyperlinks) {
  var rels = {};
  var map = this.map = {};
  if (relationships) {
    _.each(relationships, function (relationship) {
      rels[relationship.rId] = relationship.target;
    });

    _.each(hyperlinks, function (hyperlink) {
      map[hyperlink.address] = rels[hyperlink.rId];
    });
  }
};

HyperlinkMap.prototype = {
  getHyperlink: function(address) {
    return this.map[address];
  }
};

module.exports = HyperlinkMap;

==> exceljs-0.2.26.tgz: package/lib/xlsx/xform/sheet/hyperlink-map.js <==
/**
 * Copyright (c) 2016 Guyon Roche
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 */
'use strict';

var HyperlinkMap = function(relationships, hyperlinks) {
  var rels = {};
  var map = this.map = {};
  if (relationships) {
    relationships.forEach(function (relationship) {
      rels[relationship.rId] = relationship.target;
    });

    hyperlinks.forEach(function (hyperlink) {
      map[hyperlink.address] = rels[hyperlink.rId];
    });
  }
};

HyperlinkMap.prototype = {
  getHyperlink: function(address) {
    return this.map[address];
  }
};

module.exports = HyperlinkMap;
